#!/usr/bin/perl -w

	# Print From Anywhere for Mac, print queue setup.  For use by SUNY Stony Brook Students
	# Service provided by Desktop & Systems Engineering 
	# This version by Shaun Kepert, original v1.0 by Andrew Johnson
	# Last Edited: 8/28/18
	
use strict;
use warnings;

my $version = "v3.2";
my $OSversion = "10";
my $self = getlogin();
my $logpath = "/Users/" . $self . "/Library/Logs";
my $date = `/bin/date`;

my $pharosPath = "/Library/Application Support/Pharos/Popup.app";
my $xeroxPath = "/Library/Printers/PPDs/Contents/Resources/Xerox Phaser 7800DN.gz";
my $pharosLS = `/bin/ls -l '/Library/Application Support/Pharos' 2>&1`;
my $xeroxLS = `/bin/ls -l '/Library/Printers/PPDs/Contents/Resources/' | grep 'Xerox Phaser 7800' 2>&1`;

close(LOG);
open(LOG, ">$logpath/SINC_PFAclient.log");
print LOG "\n$date";
print LOG "Starting $0 - $version\n";
system ( "echo ");
system ( "echo Print From Anywhere $version, Provided by Desktop and Systems Engineering" );
system ( "echo This version by Shaun Kepert, original version by Andrew Johnson" );
system ( "echo ");
system ( "echo This script requires the Pharos Popup software and Xerox print drivers to be installed first.");
system ( "echo ");

# print LOG "$logpath\n";

	# OS Version check
$OSversion=`/usr/bin/defaults read /System/Library/CoreServices/SystemVersion ProductVersion`;
print LOG "My OS version: $OSversion";
$OSversion=`/usr/bin/defaults read /System/Library/CoreServices/SystemVersion ProductVersion | /usr/bin/cut -d \".\" -f 2`;
chomp $OSversion;
if ( $OSversion < 7 ) {
	print LOG "Your operating system version is too low, update to MacOS 10.7 or higher.\n";
	close(LOG);
	die;
}

	#Check for Pharos Popup and Xerox Printer software
	
print LOG "Checking for Pharos and Xerox software:\n";

if ( -e $pharosPath ) {
	 print LOG "Pharos software appears to be installed, found:\n";
	 print LOG "$pharosLS";
}
else {
	print LOG "WARNING! Pharos software does not appear to be installed!\n";
	print LOG "$pharosLS";
	system ("cat $logpath/SINC_PFAclient.log");
	system ("echo FAILED INSTALL - PHAROS POPUP REQUIRED");
	close (LOG);
	die;
}
if ( -e $xeroxPath ) {
	print LOG "Xerox software appears to be installed, found:\n";
	print LOG "$xeroxLS";
}
else {
	print LOG "WARNING! Xerox printer drivers do not appear to be installed!\n";
	print LOG "$xeroxLS";
	system ("cat $logpath/SINC_PFAclient.log");
	system ("echo FAILED INSTALL - XEROX PHASER DRIVER REQUIRED");
	close (LOG);
	die;
}

	# Create the Print Queue if it doesn't exist. 
print LOG "Checking for SINC_Print_From_Anywhere:\n";
my $queue=`/usr/bin/lpstat -v | /usr/bin/egrep -ic SINC_Print_From_Anywhere`; chomp $queue;
if ( $queue >= 1 ) {
	print LOG "It looks like the Queue already exists.\n";
	$queue=`/usr/bin/lpstat -p 2>&1`;
	print LOG "lpstat found:\n";
	print LOG "$queue";
}
else {
		# Install the print queue.
	print LOG "Installing the print queue.\n";
	system("/usr/sbin/lpadmin -D 'SINC Print From Anywhere' -p SINC_Print_From_Anywhere  -v 'popup://elmo.sinc.stonybrook.edu:515/mainq_web' -E -P '$xeroxPath' -o 'PageSize/Media Size':'Letter' -o printer-is-shared=false 2>&1 >> $logpath/SINC_PFAclient.log");
		# Enabling the printer just in case.
	print LOG "Enabling the print queue.\n";
	system("/usr/sbin/cupsenable \$(/usr/bin/lpstat -p | /usr/bin/grep -w 'printer' | /usr/bin/awk '{print\$2}') 2>&1 >> $logpath/SINC_PFAclient.log");
	
	$queue=`/usr/bin/lpstat -p`;
	print LOG "lpstat found:\n";
	print LOG "$queue";	
}

print LOG "Ending $0 - $version\n\n";
system ("cat $logpath/SINC_PFAclient.log");
system ("echo 'You can find the instalation log at: $logpath/SINC_PFAclient.log'");
close(LOG);
exit;
